Struct tokio::sync::broadcast::SendError[−][src]

pub struct SendError<T>(pub T);

Error returned by Sender::send.

A send operation can only fail if there are no active receivers, implying that the message could never be received. The error contains the message being sent as a payload so it can be recovered.